********************
``mplsignal.ticker``
********************

.. inheritance-diagram:: mplsignal.ticker
   :parts: 1
   :top-classes: matplotlib.ticker.Locator, matplotlib.ticker.Formatter

.. automodule:: mplsignal.ticker
   :members:
   :undoc-members:
   :show-inheritance:
